@@ -17,7 +17,7 @@
 #' res$status_code
 #' res$headers
 #'
-#' # More than 1 can be given for all searh parameters
+#' # More than 1 can be given for all search parameters
 #' bold_specimens(taxon=c('Coelioxys','Osmia'))
 #'
 #' ## curl debugging
@@ -37,11 +37,13 @@ bold_specimens <- function(taxon = NULL, ids = NULL, bin = NULL, container = NUL
       researchers=pipeornull(researchers), specimen_download=format))
   check_args_given_nonempty(args, c('taxon','ids','bin','container','institutions','researchers','geo'))
   out <- b_GET(paste0(bbase(), 'API_Public/specimen'), args, ...)
-  if(response){ out } else {
-    tt <- content(out, as = "text")
+  if (response) {
+    out
+  } else {
+    tt <- rawToChar(content(out, encoding = "UTF-8"))
     switch(format,
-           xml = xmlParse(tt),
-           tsv = read.delim(text = tt, header = TRUE, sep = "\t", stringsAsFactors=FALSE)
+           xml = xml2::read_xml(tt),
+           tsv = read.delim(text = tt, header = TRUE, sep = "\t", stringsAsFactors = FALSE)
     )
   }
 }
