@@ -38,7 +38,7 @@ check_args_given_nonempty <- function(arguments, x){
 }
 
 process_response <- function(x, y, z, w){
-  tt <- rawToChar(content(out, encoding = "UTF-8"))
+  tt <- rawToChar(content(x, "raw", encoding = "UTF-8"))
   out <- if (x$status_code > 202) "stop" else jsonlite::fromJSON(tt)
   if ( length(out) == 0 || identical(out[[1]], list()) || out == "stop" ) {
     data.frame(input = y, stringsAsFactors = FALSE)
